@@ -36,7 +36,7 @@ class PilotMemo;
 
 class KNotesAction : public ConduitAction
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	KNotesAction(
