@@ -369,7 +369,7 @@ static inline bool checkBackupDirectory( const TQString &backupDir )
 	initNoBackup( fP->fNoBackupDBs, fP->fNoBackupCreators );
 
 	fP->fDBIndex = 0;
-	TQTimer::singleShot(0,this,TQT_SLOT(backupOneDB()));
+	TQTimer::singleShot(0,this,TQ_SLOT(backupOneDB()));
 	return true;
 }
 
@@ -448,7 +448,7 @@ static inline bool checkBackupDirectory( const TQString &backupDir )
 			.arg(Pilot::fromPilot(info.name));
 		addSyncLogEntry(s);
 	}
-	TQTimer::singleShot(0,this,TQT_SLOT(backupOneDB()));
+	TQTimer::singleShot(0,this,TQ_SLOT(backupOneDB()));
 }
 
 /**
@@ -538,7 +538,7 @@ bool BackupAction::startBackupThread(DBInfo *info)
 		KPILOT_DELETE(fBackupThread);
 		// This was a successful termination.
 		addSyncLogEntry( i18n("... OK.\n"), false );
-		TQTimer::singleShot(0,this,TQT_SLOT(backupOneDB()));
+		TQTimer::singleShot(0,this,TQ_SLOT(backupOneDB()));
 		return true;
 	}
 	if (e->type() == (TQEvent::Type)Thread::TerminateFailure)
@@ -546,7 +546,7 @@ bool BackupAction::startBackupThread(DBInfo *info)
 		KPILOT_DELETE(fBackupThread);
 		// Unsuccessful termination.
 		addSyncLogEntry( i18n("Backup failed.") );
-		TQTimer::singleShot(0,this,TQT_SLOT(backupOneDB()));
+		TQTimer::singleShot(0,this,TQ_SLOT(backupOneDB()));
 		return true;
 	}
 	return SyncAction::event(e);
@@ -615,8 +615,8 @@ FileInstallAction::~FileInstallAction()
 	}
 
 	fTimer = new TQTimer(this);
-	TQObject::connect(fTimer, TQT_SIGNAL(timeout()),
-		this, TQT_SLOT(installNextFile()));
+	TQObject::connect(fTimer, TQ_SIGNAL(timeout()),
+		this, TQ_SLOT(installNextFile()));
 
 	fTimer->start(0, false);
 
@@ -1049,8 +1049,8 @@ void RestoreAction::setDirectory( const TQString &path )
 	fP->fDBIterator = fP->fDBList.begin();
 	fActionStatus = InstallingFiles;
 
-	TQObject::connect(&(fP->fTimer), TQT_SIGNAL(timeout()),
-		this, TQT_SLOT(installNextFile()));
+	TQObject::connect(&(fP->fTimer), TQ_SIGNAL(timeout()),
+		this, TQ_SLOT(installNextFile()));
 
 	fP->fTimer.start(0, false);
 	return true;
