@@ -36,7 +36,7 @@ class ConfigWizard_base3;
 
 class ConfigWizard : public KWizard
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
 	enum Mode { InDialog=0, Standalone=1 } ;
